@@ -16,11 +16,14 @@ class PacketEncoder(BaseAdapter):
     """
     This plugin will create packets based on objects entering it.
     You can set which attributes will be taken in the packet with
-    <attributes>
-       <attribute>attribute1</attribute>
-       <attribute>attribute2</attribute>
-       ...
-    </attributes>
+    
+        .. code-block:: xml
+        
+            <attributes>
+               <attribute>attribute1</attribute>
+               <attribute>attribute2</attribute>
+               <!-- ... -->
+            </attributes>
     """
     
     _design_metadata_ = dict(default_width=350)
@@ -49,21 +52,13 @@ class PacketEncoder(BaseAdapter):
                     'allow_missing_attributes', False)
 
     @component('IN', 'OUT')
-    def launch(self, values, out):
+    def launch(self, values, out):            
+        getter = self.allow_missing_attributes and\
+                 (lambda it, at: getattr(it, at, None)) or getattr
+
         for value in values:
-            packet_datas = dict()
-            for attribute_name in self.attributes:
-                if not hasattr(value, attribute_name):
-                    if not self.allow_missing_attributes:
-                        raise ValueError('Object %s has no attribute %s' %
-                                (value, attribute_name))
-                else:
-                    attribute_value = getattr(value, attribute_name)
-                    packet_datas[attribute_name] = attribute_value
-
-
-            pck = Packet(packet_datas)
-            yield pck
+            yield Packet(dict([(attr, getter(value, attr))
+                                 for attr in self.attributes]))
 
 class PacketDuplicator(BaseAdapter):
     """
